# Lazy-load

This is a simple Drupal module to lazy-load all inline images and/or iframes
defined by content authors in entity content, usually the text-format-enabled
version of textarea fields. i.e. Node and Block body content.

This module depends on the [lazysizes](https://github.com/aFarkas/lazysizes) library.
> High performance and SEO friendly lazy loader for images (responsive and normal), iframes and more, that detects any visibility changes triggered through user interaction, CSS or JavaScript without configuration.

## 3.x Features

* Now uses [lazysizes](https://github.com/aFarkas/lazysizes) library for rich features
* Supports **inline-images** and **inline-iframes** (Enabled per text-format)
* Supports **image fields** with following field formatters:
    - Colorbox `colorbox`
    - Image `image`
    - Responsive image `responsive_image`
    - Media Thumbnail `media_thumbnail`
* Supports adding field formatters via `hook_lazy_field_formatters_alter(&$formatters)`  hook
* Supports native `loading="auto"` attribute for Chrome browsers.

## Breaking changes since 2.x
> If you're looking for 8.x-2.x documentation go to https://git.drupalcode.org/project/lazy/blob/8.x-2.x/README.md

**[bLazy](http://dinbror.dk/blazy/) library replaced with [lazysizes](https://github.com/aFarkas/lazysizes).**  
If you customized bLazy configuration, you should checkout the [documentation](https://github.com/aFarkas/lazysizes/blob/gh-pages/README.md) for the lazysizes way.






## Installing via Composer

- Run `composer require --prefer-dist composer/installers` to ensure that you have the `composer/installers` package installed. This package facilitates the installation of packages into directories other than `/vendor` (e.g. `/libraries`) using Composer.


``` json
"repositories": [
    {
        "type": "composer",
        "url": "https://packages.drupal.org/8"
    },
    {
        "type": "composer",
        "url": "https://asset-packagist.org"
    },
],
"require": {
    "composer/installers": "^1.0",
    "drupal/lazy": "^3.0",
    "oomphinc/composer-installers-extender": "^1.0",
    "bower-asset/lazysizes": "^5.1"
},
"extra": {
    "installer-types": ["bower-asset", "npm-asset"],
    "installer-paths": {
        "web/core": ["type:drupal-core"],
        "web/modules/contrib/{$name}": ["type:drupal-module"],
        "web/modules/{$name}": ["type:unity-module"],
        "web/profiles/contrib/{$name}": ["type:drupal-profile"],
        "web/themes/contrib/{$name}": ["type:drupal-theme"],
        "web/themes/{$name}": ["type:unity-theme"],
        "web/libraries/{$name}": ["type:drupal-library", "type:bower-asset", "type:npm-asset"],
        "drush/contrib/{$name}": ["type:drupal-drush"]
    }
}
```

## Adding other image-based field formatters

``` php
<?php 

/**
 * Alter enabled field formatters for lazy-loading.
 *
 * @param $formatters
 *   Array of field formatters.
 *
 * @return array
 */
function hook_lazy_field_formatters_alter(&$formatters) {
    $formatters[] = 'hook_formatter';

    return $formatters;
}
```
