(function (Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.lazy = {
    attach: function attach(context, settings) {
      var lazysizes = settings.lazy.lazysizes || {};

      if ('loading' in HTMLImageElement.prototype) {
        var element = document.querySelectorAll('[loading="lazy"]');
        element.forEach(el => {
          el.setAttribute('src', el.getAttribute(lazysizes.srcAttr));
          this.removeClass(el, lazysizes.lazyClass);
          this.addClass(el, lazysizes.loadedClass);
        });
      }
      else {
        // 1. Lazysizes configuration.
        window.lazySizesConfig = window.lazySizesConfig || {};
        window.lazySizesConfig = this.extend(window.lazySizesConfig, lazysizes);
        // 2. Load all selected lazysizes plugins.
        for (let [key, path] of Object.entries(lazysizes.plugins)) {
          this.loadScript(Drupal.url(`libraries/lazysizes/plugins/${path}.min.js`));
        }
        // 3. Load the lazysizes library.
        this.loadScript(Drupal.url('libraries/lazysizes/lazysizes.min.js'));
      }
    },
    extend: function extend(obj, src) {
      Object.keys(src).forEach(function (key) { obj[key] = src[key]; });
      return obj;
    },
    hasClass: function hasClass(el, className) {
      return el.classList ? el.classList.contains(className) : new RegExp('\\b'+ className+'\\b').test(el.className);
    },
    addClass: function addClass(el, className) {
      if (el.classList) el.classList.add(className);
      else if (!hasClass(el, className)) el.className += ' ' + className;
    },
    removeClass: function removeClass(el, className) {
      if (el.classList) el.classList.remove(className);
      else el.className = el.className.replace(new RegExp('\\b'+ className+'\\b', 'g'), '');
    },
    loadScript: function loadScript(url) {
      var script = document.createElement('script'),
        scripts = document.getElementsByTagName('script')[0];
      script.src = url;
      scripts.parentNode.insertBefore(script, scripts);
    }
  }

})(Drupal, drupalSettings);
