<?php

namespace Drupal\lazy;

/**
 * Interface LazyInterface.
 */
interface LazyInterface {

  /**
   * List of available plugins.
   *
   * @return array
   */
  public function getPlugins():array ;

  /**
   * Is Lazy enabled.
   *
   * @return array|false
   */
  public function isEnabled();

  /**
   * Check whether any fields enabled.
   *
   * @param $image_fields
   *
   * @return array|false
   */
  public function isFieldsEnabled($image_fields);

  /**
   * Check whether any text-format filters enabled.
   *
   * @return array|false
   */
  public function isFiltersEnabled();

  /**
   * Checks whether lazy-load is disabled for the current path.
   *
   * @param string $disabled_paths
   *   List of paths Lazy should be disabled.
   *
   * @return bool
   *   Whether Lazy is disabled for the requested path.
   */
  public function isPathAllowed($disabled_paths): bool;

}
